@@ -26,7 +26,7 @@ mypal <- function(set=TRUE,...) {
 ##' @keywords color
 ##' @export
 Col <- function(col,alpha=0.2,locate=0) {
-    if (locate>0) colsel(locate)
+    if (locate>0) return(colsel(locate))
     
     mapply(function(x,alpha)
         do.call(rgb,as.list(c(col2rgb(x)/255,alpha))),
